AntPack
=====================================================
Tools for numbering, sequence analysis and statistical
modeling / ML for antibodies, using amino acid sequences
(not nucleotides).

.. toctree::
  :maxdepth: 1
   
  Installation and licensing <installation>


Using AntPack from Python vs from the command line
====================================================

.. toctree::
  :maxdepth: 1

   AntPack command line and Python APIs <api_background>


Antibody Numbering
=====================

.. toctree::
  :maxdepth: 1

   How antibody numbering in AntPack works <numbering_background>

   Antibody numbering <numbering_tutorial>

   Numbering example <numbering_example>


Assigning V and J genes
=======================

.. toctree::
  :maxdepth: 1
   
   VJ gene assignment tutorial <vj_gene_tutorial>

   VJ gene assignment example <vj_gene_example>


Finding developability liabilities
===================================

.. toctree::
  :maxdepth: 1

   Finding liabilities <liability_tutorial>


Humannness scoring, generative modeling and humanization
==================================================================

.. toctree::
  :maxdepth: 1

   How humanness evaluation in AntPack works <scoring_background>

   Humanness evaluation <scoring_tutorial>

   Generating new human sequences <generative_tutorial>

   Humanizing sequences <humanization_tutorial>

   Scoring and clustering examples <scoring_example>

Miscellaneous
==============

.. toctree::
  :maxdepth: 1

  About / Contact <contact>

  
* :ref:`search`
